@@ -37,21 +37,21 @@ class Mcdbot(discord.Client):
         # self.discord_logger.addHandler(handler)
         logger.remove()
         self.logger_id = logger.add(config.mcdbot_log,
-                                    level="DEBUG" if config.debug else "WARNING",
+                                    level="DEBUG" if config.debug else "INFO",
                                     backtrace=True,
                                     diagnose=config.debug,
                                     catch=False)
 
         import mcdbot.commands
-        from mcdbot.mojang_api import MojangApi
+        # from mcdbot.mojang_api import MojangApi
         from mcdbot.rcon import Rcon
         from mcdbot.redis import Redis
-        from mcdbot.whitelist import Whitelist
+        # from mcdbot.whitelist import Whitelist
 
         self.redis = Redis()
         self.rcon = Rcon()
-        self.mojang_api = MojangApi()
-        self.whitelist = Whitelist(self)
+        # self.mojang_api = MojangApi()
+        # self.whitelist = Whitelist(self)
 
         intents = discord.Intents.none()
         intents.messages = True
@@ -89,10 +89,10 @@ class Mcdbot(discord.Client):
                 except ConnectionError as ce:
                     logger.error(f"RCON connection error => {ce}")
 
-                try:
-                    await self.mojang_api.start()
-                except ConnectionError as ce:
-                    logger.error(f"Mojang API connection error => {ce}")
+                # try:
+                #     await self.mojang_api.start()
+                # except ConnectionError as ce:
+                #     logger.error(f"Mojang API connection error => {ce}")
 
                 logger.debug(f"Starting with token: {token}")
                 await self.start(token)
@@ -101,7 +101,7 @@ class Mcdbot(discord.Client):
                 raise e
             finally:
                 logger.warning("Shutting down...")
-                await self.mojang_api.stop()
+                # await self.mojang_api.stop()
                 await self.rcon.stop()
                 await self.redis.stop()
                 if not self.is_closed():
