@@ -34,7 +34,8 @@ class Redis(object):
     async def start(self):
         if not self.started:
             try:
-                self._redis = await aioredis.create_redis_pool(global_config.redis_url)
+                self._redis = await aioredis.create_redis_pool(global_config.redis_url,
+                                                               encoding=str)
                 await RedisMigrate(self._redis).start()
             except Exception as e:
                 self.started = False
